Package: zstdlite
Type: Package
Title: Fast Compression and Serialization with 'Zstandard' Algorithm
Version: 0.2.7
Authors@R: c(
    person("Mike", "Cheng", role = c("aut", "cre", 'cph'), email = "mikefc@coolbutuseless.com"),
    person("Yann", "Collet", role = c("aut"), comment = "Author of the embedded Zstandard library"),
    person("Meta Platforms, Inc. and affiliates.", role = "cph", comment = "Facebook is the copyright holder of the bundled Zstandard library")
    )
Maintainer: Mike Cheng <mikefc@coolbutuseless.com>
Description: Fast, compressed serialization of R objects using the 'Zstandard' algorithm.
    R objects can be compressed and decompressed quickly using the standard 
    serialization mechanism in R.   Raw byte vectors
    and strings are also handled directly for compatibility with compressed data created
    by other systems and programs supporting 'Zstandard' compression.   
    Dictionaries are supported for more effective compression of small data, 
    and functions are provided for training these dictionaries.
    This implementation provides an R interface to advanced features of 
    the 'Zstandard' 'C' library (available from <https://github.com/facebook/zstd>).
URL: https://github.com/coolbutuseless/zstdlite
BugReports: https://github.com/coolbutuseless/zstdlite/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.1
Copyright: This package includes code from the 'Zstandard' library
        owned by Meta Platforms, Inc. and affiliates. and created by
        Yann Collet.  See file 'inst/COPYRIGHTS' for details.
Suggests: knitr, rmarkdown, testthat, bench
Depends: R (>= 3.4.0)
VignetteBuilder: knitr
Author: Mike Cheng [aut, cre, cph],
  Yann Collet [aut] (Author of the embedded Zstandard library),
  Meta Platforms, Inc. and affiliates. [cph] (Facebook is the copyright
    holder of the bundled Zstandard library)
Built: R 4.4.0; i386-apple-darwin10.8.0; 2024-05-02 04:26:06 UTC; unix
