# Generated by roxygen2: do not edit by hand

export(zstd_cctx)
export(zstd_cctx_settings)
export(zstd_compress)
export(zstd_dctx)
export(zstd_dctx_settings)
export(zstd_decompress)
export(zstd_dict_id)
export(zstd_serialize)
export(zstd_train_dict_compress)
export(zstd_train_dict_serialize)
export(zstd_unserialize)
export(zstd_version)
useDynLib(zstdlite, .registration=TRUE)
